@@ -6,7 +6,7 @@ import textwrap
 from visidata import VisiData, Extensible, globalCommand, ColumnAttr, ColumnItem, vd, ENTER, EscapeException, drawcache, drawcache_property, LazyChainMap, asyncthread, ExpectedException, setitem
 from visidata import (options, Column, namedlist, SettableColumn,
 TypedExceptionWrapper, BaseSheet, UNLOADED,
-vd, clipdraw, ColorAttr, update_attr, colors, undoAttrFunc)
+clipdraw, ColorAttr, update_attr, colors, undoAttrFunc, vlen)
 import visidata
 
 
@@ -956,7 +956,6 @@ class SequenceSheet(Sheet):
 class IndexSheet(Sheet):
     'Base class for tabular sheets with rows that are Sheets.'
     rowtype = 'sheets'  # rowdef: Sheet
-    precious = False
 
     columns = [
         Column('name', getter=lambda c,r: r.names[-1], setter=lambda c,r,v: setitem(r.names, -1, v)),
@@ -1004,6 +1003,7 @@ class SheetsSheet(IndexSheet):
         ColumnAttr('progressPct'),
 #        ColumnAttr('threads', 'currentThreads', type=vlen),
     ]
+    precious = False
     nKeys = 1
     def reload(self):
         self.rows = self.source
@@ -1038,7 +1038,7 @@ def remove(vd, vs):
 
 
 @VisiData.api
-def push(vd, vs, pane=0):
+def push(vd, vs, pane=0, load=True):
     'Push Sheet *vs* onto ``vd.sheets`` stack for *pane* (0 for active pane, -1 for inactive pane).  Remove from other position if already on sheets stack.'
     if not isinstance(vs, BaseSheet):
         return  # return instead of raise, some commands need this
@@ -1061,7 +1061,8 @@ def push(vd, vs, pane=0):
     if vs.precious and vs not in vd.allSheets:
         vd.allSheets.append(vs)
 
-    vs.ensureLoaded()
+    if load:
+        vs.ensureLoaded()
 
 
 @VisiData.lazy_property
@@ -1148,11 +1149,13 @@ def async_deepcopy(sheet, rowlist):
     return ret
 
 
-IndexSheet.class_options.header = 0
-IndexSheet.class_options.skip = 0
+IndexSheet.options.header = 0
+IndexSheet.options.skip = 0
 
 BaseSheet.init('pane', lambda: 1)
 
+Sheet.init('_ordering', list, copy=True)  # (col:Column, reverse:bool)
+
 globalCommand('S', 'sheets-stack', 'vd.push(vd.sheetsSheet)', 'open Sheets Stack: join or jump between the active sheets on the current stack')
 globalCommand('gS', 'sheets-all', 'vd.push(vd.allSheetsSheet)', 'open Sheets Sheet: join or jump between all sheets from current session')
 
@@ -1200,16 +1203,17 @@ BaseSheet.addCommand('zZ', 'splitwin-input', 'vd.options.disp_splitwin_pct = inp
 
 BaseSheet.addCommand('^L', 'redraw', 'vd.redraw(); sheet.refresh()', 'Refresh screen')
 BaseSheet.addCommand(None, 'guard-sheet', 'options.set("quitguard", True, sheet); status("guarded")', 'Set quitguard on current sheet to confirm before quit')
+BaseSheet.addCommand(None, 'guard-sheet-off', 'options.set("quitguard", False, sheet); status("unguarded")', 'Unset quitguard on current sheet to not confirm before quit')
 BaseSheet.addCommand(None, 'open-source', 'vd.push(source)', 'jump to the source of this sheet')
 
 BaseSheet.bindkey('KEY_RESIZE', 'redraw')
 
 BaseSheet.addCommand('A', 'open-new', 'vd.push(vd.newSheet("unnamed", 1))', 'Open new empty sheet')
 
-Sheet.addCommand('^', 'rename-col', 'vd.addUndoColNames([cursorCol]); cursorCol.name = editCell(cursorVisibleColIndex, -1)', 'edit name of current column')
-Sheet.addCommand('z^', 'rename-col-selected', 'updateColNames(selectedRows or [cursorRow], [sheet.cursorCol], overwrite=True)', 'set name of current column to combined contents of current cell in selected rows (or current row)')
-Sheet.addCommand('g^', 'rename-cols-row', 'updateColNames(selectedRows or [cursorRow], sheet.visibleCols)', 'set names of all unnamed visible columns to contents of selected rows (or current row)')
-Sheet.addCommand('gz^', 'rename-cols-selected', 'updateColNames(selectedRows or [cursorRow], sheet.visibleCols, overwrite=True)', 'set names of all visible columns to combined contents of selected rows (or current row)')
+Sheet.addCommand('^', 'rename-col', 'vd.addUndoColNames([cursorCol]); cursorCol.name = editCell(cursorVisibleColIndex, -1)', 'rename current column')
+Sheet.addCommand('z^', 'rename-col-selected', 'updateColNames(selectedRows or [cursorRow], [sheet.cursorCol], overwrite=True)', 'rename current column to combined contents of current cell in selected rows (or current row)')
+Sheet.addCommand('g^', 'rename-cols-row', 'updateColNames(selectedRows or [cursorRow], sheet.visibleCols)', 'rename all unnamed visible columns to contents of selected rows (or current row)')
+Sheet.addCommand('gz^', 'rename-cols-selected', 'updateColNames(selectedRows or [cursorRow], sheet.visibleCols, overwrite=True)', 'rename all visible columns to combined contents of selected rows (or current row)')
 BaseSheet.addCommand(None, 'rename-sheet', 'sheet.name = input("rename sheet to: ", value=sheet.name)', 'Rename current sheet')
 
 
